@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-    A module for the manipulation of disparate data streams as single, coherent data streams.
+    A module for the manipulation of disparate data streams.
 """
 """
     split_file_reader
-    Copyright (C) 2020  Xavier Halloran, United States
+    Copyright (C) 2021  Xavier Halloran, United States
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 """
 
 
-__version__ = '0.0.3'
+__version__ = '0.0.5'
 
 import logging
 
@@ -30,4 +30,6 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 from .split_file_reader import SplitFileReader
 
-__all__ = ["SplitFileReader"]
+__all__ = [
+    "SplitFileReader",
+]
